==> yams-1.0.0.tar.gz: yams-1.0.0/src/simulator.h <==
/* yams -- Yet Another Machine Simulator
   Copyright (C) 2002 Juha Aatrokoski, Timo Lilja, Leena Salmela,
   Teemu Takanen, Aleksi Virtanen

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
   USA.

   $Id: simulator.h,v 1.20 2002/11/20 12:44:33 ttakanen Exp $
*/

#ifndef YAMS_SIMULATOR_H
#define YAMS_SIMULATOR_H

#include <sys/types.h>

#include "cpu.h"
#include "memory.h"
#include "misc.h"
#include "device.h"

typedef struct _hardware_t {
    memory_t *memory;

    cpu_t **cpus;
    int num_cpus;
    uint32_t clockspeed; /* in Hz */

    device_t *devices;
    int num_devices;

    uint64_t cycle_count;

    int running;
    uint32_t breakpoint;
} hardware_t;

extern hardware_t *hardware;

void simulator_create(int mem_pages, int num_cpus, int clock_speed);
void simulator_add_device(device_t *dev);
void simulator_init();
void simulator_run(uint64_t stop_at_cycle);

#endif /* YAMS_SIMULATOR_H */

==> yams-1.3.0.tar.gz: yams-1.3.0/src/simulator.h <==
/* yams -- Yet Another Machine Simulator
   Copyright (C) 2002-2005 Juha Aatrokoski, Timo Lilja, Leena Salmela,
   Teemu Takanen, Aleksi Virtanen

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
   USA.

   $Id: simulator.h,v 1.22 2005/06/05 14:20:55 jaatroko Exp $
*/

#ifndef YAMS_SIMULATOR_H
#define YAMS_SIMULATOR_H

#include <sys/types.h>

#include "cpu.h"
#include "memory.h"
#include "misc.h"
#include "device.h"
#include "plugio.h"

typedef struct _hardware_t {
    memory_t *memory;

    cpu_t **cpus;
    int num_cpus;
    uint32_t clockspeed; /* in Hz */

    device_t *devices;
    int num_devices;

    uint64_t cycle_count;

    int running;
    uint32_t breakpoint;
} hardware_t;

extern hardware_t *hardware;

void simulator_create(int mem_pages, int num_cpus, int clock_speed, 
                      int cpu_irq);
void simulator_add_device(device_t *dev);
void simulator_add_mmap(pluggable_device_t *dev);
void simulator_init();
void simulator_run(uint64_t stop_at_cycle);

#endif /* YAMS_SIMULATOR_H */
